SWDEV-436405 - Add hipGetDevicePropertiesR0000 and hipChooseDeviceR0000 to hip dispatch table
Change-Id: I5b373ac030502eb88477d20a1d216bc48369b51d
This commit is contained in:
committed by
Anusha Godavarthy Surya
orang tua
9551d48e7f
melakukan
3e72b8d1e1
@@ -111,9 +111,12 @@ hipError_t hipBindTextureToMipmappedArray(const textureReference* tex,
|
||||
const hipChannelFormatDesc* desc) {
|
||||
return hip::GetHipDispatchTable()->hipBindTextureToMipmappedArray_fn(tex, mipmappedArray, desc);
|
||||
}
|
||||
hipError_t hipChooseDevice(int* device, const hipDeviceProp_t* prop) {
|
||||
extern "C" hipError_t hipChooseDevice(int* device, const hipDeviceProp_t* prop) {
|
||||
return hip::GetHipDispatchTable()->hipChooseDevice_fn(device, prop);
|
||||
}
|
||||
extern "C" hipError_t hipChooseDeviceR0000(int* device, const hipDeviceProp_tR0000* properties) {
|
||||
return hip::GetHipDispatchTable()->hipChooseDeviceR0000_fn(device, properties);
|
||||
}
|
||||
extern "C" hipError_t hipConfigureCall(dim3 gridDim, dim3 blockDim, size_t sharedMem,
|
||||
hipStream_t stream) {
|
||||
return hip::GetHipDispatchTable()->hipConfigureCall_fn(gridDim, blockDim, sharedMem, stream);
|
||||
@@ -407,8 +410,11 @@ hipError_t hipGetDeviceCount(int* count) {
|
||||
hipError_t hipGetDeviceFlags(unsigned int* flags) {
|
||||
return hip::GetHipDispatchTable()->hipGetDeviceFlags_fn(flags);
|
||||
}
|
||||
hipError_t hipGetDeviceProperties(hipDeviceProp_t* prop, int deviceId) {
|
||||
return hip::GetHipDispatchTable()->hipGetDeviceProperties_fn(prop, deviceId);
|
||||
extern "C" hipError_t hipGetDevicePropertiesR0600(hipDeviceProp_tR0600* prop, int deviceId) {
|
||||
return hip::GetHipDispatchTable()->hipGetDevicePropertiesR0600_fn(prop, deviceId);
|
||||
}
|
||||
extern "C" hipError_t hipGetDevicePropertiesR0000(hipDeviceProp_tR0000* prop, int device) {
|
||||
return hip::GetHipDispatchTable()->hipGetDevicePropertiesR0000_fn(prop, device);
|
||||
}
|
||||
const char* hipGetErrorName(hipError_t hip_error) {
|
||||
return hip::GetHipDispatchTable()->hipGetErrorName_fn(hip_error);
|
||||
|
||||
Reference in New Issue
Block a user